@@ -19,10 +19,11 @@
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef _REGEXP_CACHE_H_
-#define _REGEXP_CACHE_H_
+#ifndef REGEXP_CACHE_H_
+#define REGEXP_CACHE_H_
 
 #include <QList>
+#include <QSet>
 #include <QRegularExpression>
 
 class RegExpCache
@@ -37,6 +38,7 @@ public:
 
 private:
     QList<QRegularExpression> m_regexpCache;
+    QSet<QString> m_exactMatches;
 };
 
 #endif
